===============================================================
devpi-client: manage devpi-server, Python packaging and testing
===============================================================

The ``devpi`` command line tool is typically used in conjunction
with `devpi-server <https://pypi.org/project/devpi-server/>`_.
It allows to upload, test and install packages from devpi indexes.

See https://doc.devpi.net for quickstart and more documentation.

Support
=======

If you find a bug, use the `issue tracker at Github`_.

For general questions use the #devpi IRC channel on `freenode.net`_ or the `devpi-dev@python.org mailing list`_.

For support contracts and paid help contact `merlinux.eu`_.

.. _issue tracker at Github: https://github.com/devpi/devpi/issues/
.. _freenode.net: https://freenode.net/
.. _devpi-dev@python.org mailing list: https://mail.python.org/mailman3/lists/devpi-dev.python.org/
.. _merlinux.eu: https://merlinux.eu
